@@ -119,24 +119,24 @@ class BatchDataset(FEDataset):
         """Split this dataset into multiple smaller datasets.
 
         This function enables several types of splitting:
-            1. Splitting by fractions.
-                ```python
-                ds = fe.dataset.FEDataset(...)  # len(ds) == 1000
-                ds2 = ds.split(0.1)  # len(ds) == 900, len(ds2) == 100
-                ds3, ds4 = ds.split(0.1, 0.2)  # len(ds) == 630, len(ds3) == 90, len(ds4) == 180
-                ```
-            2. Splitting by counts.
-                ```python
-                ds = fe.dataset.FEDataset(...)  # len(ds) == 1000
-                ds2 = ds.split(100)  # len(ds) == 900, len(ds2) == 100
-                ds3, ds4 = ds.split(90, 180)  # len(ds) == 630, len(ds3) == 90, len(ds4) == 180
-                ```
-            3. Splitting by indices.
-                ``python
-                ds = fe.dataset.FEDataset(...)  # len(ds) == 1000
-                ds2 = ds.split([87,2,3,100,121,158])  # len(ds) == 994, len(ds2) == 6
-                ds3 = ds.split(range(100))  # len(ds) == 894, len(ds3) == 100
-                ```
+        1. Splitting by fractions.
+            ```python
+            ds = fe.dataset.FEDataset(...)  # len(ds) == 1000
+            ds2 = ds.split(0.1)  # len(ds) == 900, len(ds2) == 100
+            ds3, ds4 = ds.split(0.1, 0.2)  # len(ds) == 630, len(ds3) == 90, len(ds4) == 180
+            ```
+        2. Splitting by counts.
+            ```python
+            ds = fe.dataset.FEDataset(...)  # len(ds) == 1000
+            ds2 = ds.split(100)  # len(ds) == 900, len(ds2) == 100
+            ds3, ds4 = ds.split(90, 180)  # len(ds) == 630, len(ds3) == 90, len(ds4) == 180
+            ```
+        3. Splitting by indices.
+            ```python
+            ds = fe.dataset.FEDataset(...)  # len(ds) == 1000
+            ds2 = ds.split([87,2,3,100,121,158])  # len(ds) == 994, len(ds2) == 6
+            ds3 = ds.split(range(100))  # len(ds) == 894, len(ds3) == 100
+            ```
 
         Args:
             *fractions: Floating point values will be interpreted as percentages, integers as an absolute number of
@@ -166,6 +166,9 @@ class BatchDataset(FEDataset):
             results = results[0]
         return results
 
+    def __getstate__(self) -> Dict[str, List[Dict[Any, Any]]]:
+        return {'datasets': [ds.__getstate__() if hasattr(ds, '__getstate__') else {} for ds in self.datasets]}
+
     def summary(self) -> DatasetSummary:
         """Generate a summary representation of this dataset.
         Returns:
