@@ -1,3 +1,17 @@
+# Copyright 2021 The FastEstimator Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ==============================================================================
 from typing import Any
 
 import matplotlib.pyplot as plt
@@ -17,13 +31,13 @@ def is_equal(obj1: Any, obj2: Any, assert_type: bool = True, assert_dtype: bool
     with elements such as int, float, np.ndarray, tf.Tensor, tf.Varaible, torch.Tensor
 
     Args:
-        obj1: input object 1
-        obj2: input object 2
-        assert_type: whether to assert the same data type
-        assert_dtype: whether to assert the same dtype in case of nd.array, tf.Tensor, torch.Tensor
+        obj1: Input object 1
+        obj2: Input object 2
+        assert_type: Whether to assert the same data type
+        assert_dtype: Whether to assert the same dtype in case of nd.array, tf.Tensor, torch.Tensor
 
     Returns:
-        boolean of whether those two object are equal
+        Boolean of whether those two object are equal
     """
     if assert_type and type(obj1) != type(obj2):
         return False
@@ -143,7 +157,7 @@ class MockBetaDistribution:
         elif self.framework == 'torch':
             return torch.Tensor([0.5])
         else:
-            raise ValueError("Unrecognized framework {}".format(framework))
+            raise ValueError("Unrecognized framework {}".format(self.framework))
 
 
 class MockUniformDistribution:
@@ -156,7 +170,7 @@ class MockUniformDistribution:
         elif self.framework == 'torch':
             return torch.Tensor([0.25])
         else:
-            raise ValueError("Unrecognized framework {}".format(framework))
+            raise ValueError("Unrecognized framework {}".format(self.framework))
 
 
 def sample_system_object():
@@ -192,15 +206,15 @@ def sample_system_object_torch():
 
 
 def check_img_similar(img1: np.ndarray, img2: np.ndarray, ptol: int = 3, ntol: float = 0.01) -> bool:
-    """ check whether img1 and img2 array are similar based on pixel to pixel comparision
+    """Check whether img1 and img2 array are similar based on pixel to pixel comparision
     Args:
-        img1: image 1
-        img2: image 2
-        ptol: pixel value tolerance
-        ntol: number of pixel difference tolerace rate
+        img1: Image 1
+        img2: Image 2
+        ptol: Pixel value tolerance
+        ntol: Number of pixel difference tolerace rate
 
     Returns:
-        boolean of whether the images are similar
+        Boolean of whether the images are similar
     """
     if img1.shape == img2.shape:
         diff = np.abs(img1.astype(np.float32) - img2.astype(np.float32))
@@ -216,22 +230,22 @@ def img_to_rgb_array(path: str) -> np.ndarray:
     """Read png file to numpy array (RGB)
 
     Args:
-        path: image path
+        path: Image path
 
     Returns:
-        image nump yarray
+        Image numpy array
     """
     return np.asarray(Image.open(path).convert('RGB'))
 
 
 def fig_to_rgb_array(fig: plt.Figure) -> np.ndarray:
-    """convert image in plt.Figure to numpy array
+    """Convert image in plt.Figure to numpy array
 
     Args:
-        fig: input figure object
+        fig: Input figure object
 
     Returns:
-        image array
+        Image array
     """
     fig.canvas.draw()
     buf = fig.canvas.tostring_rgb()
