@@ -32,13 +32,13 @@ from fastestimator.backend.permute import permute
 from fastestimator.backend.reduce_sum import reduce_sum
 from fastestimator.backend.reshape import reshape
 from fastestimator.backend.squeeze import squeeze
-from fastestimator.backend.to_number import to_number
 from fastestimator.backend.to_tensor import to_tensor
 from fastestimator.network import BaseNetwork, TFNetwork
 from fastestimator.trace.trace import Trace
 from fastestimator.util.data import Data
-from fastestimator.util.util import DefaultKeyDict, is_number, to_list, to_set
 from fastestimator.util.img_data import ImgData
+from fastestimator.util.traceability_util import traceable
+from fastestimator.util.util import DefaultKeyDict, is_number, to_list, to_number, to_set
 
 # https://github.com/pytorch/pytorch/issues/30966
 tf.io.gfile = tb.compat.tensorflow_stub.io.gfile
@@ -50,6 +50,8 @@ Tensor = TypeVar('Tensor', tf.Tensor, torch.Tensor)
 class _BaseWriter:
     """A class to write various types of data into TensorBoard summary files.
 
+    This class is intentionally not @traceable.
+
     Args:
         root_log_dir: The directory into which to store a new directory corresponding to this experiment's summary data
         time_stamp: The timestamp of this experiment (used as a folder name within `root_log_dir`).
@@ -63,12 +65,11 @@ class _BaseWriter:
                                               (SummaryWriter(log_dir=os.path.join(root_log_dir, time_stamp, key))))
         self.network = network
 
-    def write_epoch_models(self, mode: str, data: Data) -> None:
+    def write_epoch_models(self, mode: str) -> None:
         """Write summary graphs for all of the models in the current epoch.
 
         Args:
             mode: The current mode of execution ('train', 'eval', 'test', 'infer').
-            data: A set of batch data
         """
         raise NotImplementedError
 
@@ -185,6 +186,8 @@ class _BaseWriter:
 class _TfWriter(_BaseWriter):
     """A class to write various TensorFlow data into TensorBoard summary files.
 
+    This class is intentionally not @traceable.
+
     Args:
         root_log_dir: The directory into which to store a new directory corresponding to this experiment's summary data
         time_stamp: The timestamp of this experiment (used as a folder name within `root_log_dir`).
@@ -197,7 +200,7 @@ class _TfWriter(_BaseWriter):
         self.tf_summary_writers = DefaultKeyDict(
             lambda key: (tf.summary.create_file_writer(os.path.join(root_log_dir, time_stamp, key))))
 
-    def write_epoch_models(self, mode: str, data: Data) -> None:
+    def write_epoch_models(self, mode: str) -> None:
         with self.tf_summary_writers[mode].as_default(), summary_ops_v2.always_record_summaries():
             summary_ops_v2.graph(backend.get_graph(), step=0)
             for model in self.network.epoch_models:
@@ -232,13 +235,12 @@ class _TfWriter(_BaseWriter):
 
 class _TorchWriter(_BaseWriter):
     """A class to write various Pytorch data into TensorBoard summary files.
+
+    This class is intentionally not @traceable.
     """
-    def write_epoch_models(self, mode: str, data: Data) -> None:
+    def write_epoch_models(self, mode: str) -> None:
         for model in self.network.epoch_models:
-            model_op = next(filter(lambda op: model is op.model, self.network.epoch_ops))
-            inputs = [data[key] for key in model_op.inputs]
-            if len(inputs) == 1 and not model_op.in_list:
-                inputs = inputs[0]
+            inputs = model.fe_input_spec.get_dummy_input()
             self.summary_writers[mode].add_graph(model, input_to_model=inputs)
 
     def write_weights(self, mode: str, models: Iterable[Model], step: int, visualize: bool) -> None:
@@ -257,6 +259,7 @@ class _TorchWriter(_BaseWriter):
                                                               dataformats='NHWC')
 
 
+@traceable()
 class TensorBoard(Trace):
     """Output data for use in TensorBoard.
 
@@ -371,7 +374,7 @@ class TensorBoard(Trace):
 
     def on_batch_end(self, data: Data) -> None:
         if self.write_graph and self.system.network.epoch_models.symmetric_difference(self.painted_graphs):
-            self.writer.write_epoch_models(mode=self.system.mode, data=data)
+            self.writer.write_epoch_models(mode=self.system.mode)
             self.painted_graphs = self.system.network.epoch_models
         if self.system.mode != 'train':
             return
